<?php
date_default_timezone_set('Asia/Tokyo');
mb_language("Japanese");
mb_internal_encoding("UTF-8");
mb_regex_encoding('UTF-8');

// for php_imagick.dll
define("IMAGICK_CSV_URL",     "http://pc.nekonotecafe.com/imagick/imagick.csv");
define("NOT_INSTALLED",     "not installed");

// 5.5以上かチェックしてから
$ret = get_php_info();
$imagick_execute_image = "";
if ($ret["installed_imagick_version"] != NOT_INSTALLED) {
	$imagick_execute_image = check_imagick();
}
$imagick_csv = file(IMAGICK_CSV_URL);

$php_imagick_lists = array();
$image_magick_lists = array();

foreach ($imagick_csv as $line) {
	$clms = explode(",", str_replace(PHP_EOL, "", $line));

	if ($clms[0] == "php_imagick" && $clms[2] == $ret["php_major_ver"] &&  $clms[3] == $ret["thread_safe"] && $clms[4] == $ret["vc"] && $clms[5] == $ret["architecture"]) {
		//		var_dump($clms);
		$php_imagick_lists[$clms[7]] = "<a href=\"" . $clms[6] . "\">" . $clms[7] . ".zip</a>";
	} else if ($clms[0] == "image_magick" && $clms[4] == $ret["vc"] && $clms[5] == $ret["architecture"]) {
		//		var_dump($clms);
		$image_magick_lists[$clms[7]] = "<a href=\"" . $clms[6] . "\">" . $clms[7] . ".zip</a>";
	}
}

function check_imagick()
{
	$text = "OK! This words is created by imagick!!";

	/* Create Imagick objects */
	$image = new Imagick();
	$draw = new ImagickDraw();
	$color = new ImagickPixel('#00FF00');
	$background = new ImagickPixel('none'); // Transparent

	/* Font properties */
	$draw->setFontSize(20);
	$draw->setFillColor($color);
	/* Get font metrics */
	$metrics = $image->queryFontMetrics($draw, $text);

	/* Create text */
	$draw->annotation(0, $metrics['ascender'], $text);

	/* Create image */
	$image->newImage($metrics['textWidth'], $metrics['textHeight'], $background);
	$image->setImageFormat('png');
	$image->drawImage($draw);

	/* Save image */
	$img = base64_encode($image);
	return "<img src=\"data:image/png;base64,$img\">";
}
function get_php_info()
{

	// microsoft compiler version
	$msvc_ver = array("2012" => 11, "2015" => 14, "2017" => 15, "2019" => 16);
	ob_start();
	phpinfo();
	$pinfo = ob_get_contents();
	ob_end_clean();

	$lines = explode("\n", $pinfo);
	$installed_imagick_version = NOT_INSTALLED;
	foreach ($lines as $line) {

		$xmlObject = @simplexml_load_string($line);

		//	var_dump($xmlObject);
		if (isset($xmlObject->td)) {

			if (preg_match("/PHP Version/", $xmlObject->td[0]) === 1) {
				$php_ver = explode(".", trim($xmlObject->td[1]));
				$php_major_ver = $php_ver[0] . "." . $php_ver[1];
			} else if (preg_match("/Compiler/", $xmlObject->td[0]) === 1) {

				preg_match("/MSVC(\d{1,2})/", $xmlObject->td[1], $matches);
				if (isset($matches[1])) {
					$vc = "vc" . $matches[1];
				} else {
					preg_match("/Visual C\+\+ (\d{4})/", $xmlObject->td[1], $matches);
					$vc = "vc" . $msvc_ver[$matches[1]];
				}
			} else if (preg_match("/Loaded Configuration File/", $xmlObject->td[0]) === 1) {
				$php_ini = trim($xmlObject->td[1]);
			} else if (preg_match("/Thread Safety/", $xmlObject->td[0]) === 1) {
				$ts_list = array("enabled" => "ts", "disabled" => "nts");
				$thread_safe = $ts_list[trim($xmlObject->td[1])];
			} else if (preg_match("/Architecture/", $xmlObject->td[0]) === 1) {
				$architecture = trim($xmlObject->td[1]);
			} else if (preg_match("/Imagick compiled with ImageMagick version/", $xmlObject->td[0]) === 1 || preg_match("/ImageMagick version/", $xmlObject->td[0]) === 1) {
				$installed_imagick_version = trim($xmlObject->td[1]);
			} else if (preg_match("/^extension_dir/", $xmlObject->td[0]) === 1) {
				$extension_dir = $xmlObject->td[1];
			}
		}
	}
	return array("php_major_ver" => $php_major_ver, "vc" => $vc, "thread_safe" => $thread_safe, "architecture" => $architecture,  "php_ini" => $php_ini,  "installed_imagick_version" => $installed_imagick_version,  "extension_dir" => $extension_dir);
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head>
	<style type="text/css">
		body {
			background-color: #ffffff;
			color: #000000;
		}

		table {
			border-collapse: collapse;
		}

		td,
		th {
			border: 1px solid #000000;
			font-size: 75%;
			vertical-align: baseline;
		}

		h1 {
			font-size: 150%;
		}

		h2 {
			font-size: 125%;
		}

		.e {
			background-color: #ccccff;
			font-weight: bold;
			color: #000000;
		}

		.v {
			background-color: #cccccc;
			color: #000000;
		}
	</style>
	<title>imagick info</title>
	<meta name="ROBOTS" content="NOINDEX,NOFOLLOW,NOARCHIVE" />
</head>

<body>
	<div>
		<h2>This PC's infomation (created by phpinfo() )</h2>
		<table border="0" cellpadding="3" width="600">
			<tr>
				<td class="e">PHP Major Version</td>
				<td class="v"><?php print $ret["php_major_ver"]; ?> </td>
			</tr>
			<tr>
				<td class="e">Thread Safety</td>
				<td class="v"><?php print $ret["thread_safe"]; ?> </td>
			</tr>
			<tr>
				<td class="e">Compiler</td>
				<td class="v"><?php print $ret["vc"]; ?> </td>
			</tr>
			<tr>
				<td class="e">Architecture</td>
				<td class="v"><?php print $ret["architecture"]; ?> </td>
			</tr>
			<tr>
				<td class="e">PHP Loaded Configuration File<br>(php.ini)</td>
				<td class="v"><?php print $ret["php_ini"]; ?> </td>
			</tr>
			<tr>
				<td class="e">PHP Extension dir</td>
				<td class="v"><?php print $ret["extension_dir"]; ?> </td>
			</tr>
			<tr>
				<td class="e">Installed Imagick Version</td>
				<td class="v">
					<?php
					print $ret["installed_imagick_version"];
					?> </td>
			</tr>
			<tr>
				<td class="e">Imagick test result</td>
				<td class="v">
					<?php
					print $imagick_execute_image;
					?> </td>
			</tr>
		</table><br />
		<h2>1) available Imagick dll zip file</h2>
		<table border="0" cellpadding="3" width="600">
			<tr>
				<td class="e">php extension and core dll's<br>php_imagick.dll + *.dll<br><a href="https://windows.php.net/downloads/pecl/releases/imagick/">more PECL site</a></td>
				<td class="v">
					<?php
					if (count($php_imagick_lists) == 0) {
						print "no files";
					} else {
						krsort($php_imagick_lists);
						$first_php_imagick = current($php_imagick_lists);
						$first_php_imagick_key = key($php_imagick_lists);
						print $first_php_imagick . "<br>";
						// foreach ($php_imagick_lists as $php_imagick) {
						// 	print $php_imagick . "<br>";
						// 	break;
						// }
					}
					?>
				</td>
			</tr>
			<tr>
				<td class="e">Image Magick<br><a href="https://windows.php.net/downloads/pecl/deps/">more PECL site</a></td>
				<td class="v">
					<?php
					if (count($image_magick_lists) == 0) {
						print "no files";
					} else {
						krsort($image_magick_lists);
						$first_image_magick = current($image_magick_lists);
						$first_image_magick_key = key($image_magick_lists);
						print $first_image_magick . "<br>";
						// foreach ($image_magick_lists as $imagick) {
						// 	print $imagick . "<br>";
						// 	break;
						// }
					}
					?>
				</td>
			</tr>
		</table><br />

		<h3>2) download and extract 2 zip files above.(click link)</h3>
		<h3>3) copy php_imagick.dll to php exetension dir</h3>
		<?php
		print "<pre><code class=\"prettyprint\">DOS command> cp (extract dir)/" . $first_php_imagick_key . "/php_imagick.dll {$ret["extension_dir"]} </code></pre>";
		?>
		<h3>4) copy extensions dll to ImageMagick bin dir</h3>
		<?php
		print "<pre><code class=\"prettyprint\">DOS command> cp (extract dir)/" . $first_php_imagick_key . "/*.dll (extract dir)/" . $first_image_magick_key . "/bin </code></pre>";
		?>
		<h3>5) add ImageMagick exetension to php.ini</h3>
		<?php
		print "<pre><code class=\"prettyprint\">DOS command> start {$ret["php_ini"]} </code></pre>";

		if ($ret["php_major_ver"] >= 7.2) {
			print "<pre><code class=\"prettyprint\"> extension=imagick </code></pre>";
		} else {
			print "<pre><code class=\"prettyprint\"> extension=php_imagick.dll </code></pre>";
		}
		?>
		<h3>6) add ImageMagick *binary path* to system environment variables[Path]</h3>
		<?php
		print "<pre><code class=\"prettyprint\"> (extract dir)/" . $first_image_magick_key . "/bin </code></pre>";
		?>
		<h3>7) restart pc & redisplay this page. </h3>
		<footer>copyright 2021- <a href="https://nekonotecafe.com">NEKONOTECAFE SE</a></footer>
	</div>
</body>

</html>